Per contatti - The Breakfast Review - la tua guida alla colazione e brunch
Description: Ciao, e ben arrivati: sì, questo è il posto giusto in cui prendere contatti con noi. Ci sono diverse domande che possono trovare risposta e alcune possiamo
Date: 2011-07-03T09:30:39+00:00

# Per contatti

Ciao, e ben arrivati: sì, questo è il posto giusto in cui prendere contatti con noi.

Ci sono diverse domande che possono trovare risposta e alcune possiamo già vederle subito insieme: ad esempio, perché non c’è la vostra città? Perché non abbiamo ancora un breakfast-reviewer da quelle parti. O magari vi chiedete che ne è del vostro locale preferito “ma è mai possibile che non se ne siano accorti”? Uhm, vediamo: sì, è probabile che ce ne siamo accorti e, altrettanto probabilmente, stiamo dandoci da fare per. O, ultimissima istanza (molto poco probabile ma sarebbe sbagliato ritenere impossibile), abbiamo per adesso deciso di aspettare.

Un esempio del genere, per dire, è la ricerca. Sappiamo che non c’è la ricerca e per adesso abbiamo deciso di aspettare ancora un pochino.

The Breakfast Review è un’idea e come tutte le idee è migliorabile, questo è il punto. E per migliorare abbiamo bisogno di un sacco di cose, tra queste anche della vostra opinione. Ci saranno delle volte che avrete bisogno di dirci qualche cosa, questa form qui sulla destra è il posto migliore per farcelo sapere.

Ma ci sono anche altri due casi: il primo caso è quello che vogliate proporvi come recensori, e ne siamo molto felici e se volete cominciare anche subito siamo qui apposta, il metodo è sempre lo stesso, compilate e inviate la richiesta e prendiamo accordi al volo; poi dobbiamo darvi tutta una serie di informazioni su come vengono fatte le recensioni.

Un altro caso ancora è che vogliate contattarci per questioni di “progetto”, che è un concetto che va dalla pubblicità a cose anche più ampie. E allora selezionate la voce giusta come oggetto della form e spedite, siamo tutto orecchi e soprattutto ci piace un sacco vedere se altre grandi idee possono unirsi alla nostra e vedere che ne esce.

Insomma: a presto.

- Nome*
  Nome Cognome
- Email*
- Newsletter
  - già che ci siamo iscrivetemi alla vostra newsletter
  - voglio ricevere anche le offerte di prodotti che potrebbero interessarmi
- Oggetto*
- Altro motivo del contatto
- Testo*
- Consenso*
  - ho letto la policy sulla privacy di The Breakfast Review
- Consenso esteso*
  - accetto e do il mio consenso esplicito

guarda la mappa

#### Scopri le colazioni a

Perché questo sito funzioni, e perché funzioni bene, ma soprattutto perché vi piaccia, utilizziamo i cookies, come del resto ogni altro sito al mondo. Purtroppo chi si occupa di privacy non ha la più vaga idea di cosa faccia e ci costringe a notificarvi una pagina che vi dice cosa ne facciamo dei vostri dati. Che poi vorremmo farveli leggere per vedere se vi riconoscete.
Ecco qui (leggetele) le nostre linee guida sui cookies
CHIUDI